==> webkit2gtk_2.35.1.orig.tar.xz: webkitgtk-2.35.1/Source/WebCore/Modules/WebGPU/GPURenderPassDepthStencilAttachment.h <==
/*
 * Copyright (C) 2021 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include "GPUIntegralTypes.h"
#include "GPULoadOp.h"
#include "GPUStoreOp.h"
#include "GPUTextureView.h"
#include <pal/graphics/WebGPU/WebGPURenderPassDepthStencilAttachment.h>
#include <variant>
#include <wtf/RefPtr.h>

namespace WebCore {

struct GPURenderPassDepthStencilAttachment {
    PAL::WebGPU::RenderPassDepthStencilAttachment convertToBacking() const
    {
        ASSERT(view);
        return {
            view->backing(),
            WTF::switchOn(depthLoadValue, [&] (GPULoadOp loadOp) -> std::variant<PAL::WebGPU::LoadOp, float> {
                return WebCore::convertToBacking(loadOp);
            }, [&] (float f) -> std::variant<PAL::WebGPU::LoadOp, float> {
                return f;
            }),
            WebCore::convertToBacking(depthStoreOp),
            depthReadOnly,
            WTF::switchOn(stencilLoadValue, [&] (GPULoadOp loadOp) -> std::variant<PAL::WebGPU::LoadOp, PAL::WebGPU::StencilValue> {
                return WebCore::convertToBacking(loadOp);
            }, [&] (GPUStencilValue stencilValue) -> std::variant<PAL::WebGPU::LoadOp, PAL::WebGPU::StencilValue> {
                return stencilValue;
            }),
            WebCore::convertToBacking(stencilStoreOp),
            stencilReadOnly,
        };
    }

    GPUTextureView* view;

    std::variant<GPULoadOp, float> depthLoadValue;
    GPUStoreOp depthStoreOp;
    bool depthReadOnly;

    std::variant<GPULoadOp, GPUStencilValue> stencilLoadValue;
    GPUStoreOp stencilStoreOp;
    bool stencilReadOnly;
};

}

==> webkit2gtk_2.35.2.orig.tar.xz: webkitgtk-2.35.2/Source/WebCore/Modules/WebGPU/GPURenderPassDepthStencilAttachment.h <==
/*
 * Copyright (C) 2021 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include "GPUIntegralTypes.h"
#include "GPULoadOp.h"
#include "GPUStoreOp.h"
#include "GPUTextureView.h"
#include <pal/graphics/WebGPU/WebGPURenderPassDepthStencilAttachment.h>
#include <variant>
#include <wtf/RefPtr.h>

namespace WebCore {

struct GPURenderPassDepthStencilAttachment {
    PAL::WebGPU::RenderPassDepthStencilAttachment convertToBacking() const
    {
        ASSERT(view);
        return {
            view->backing(),
            WTF::switchOn(depthLoadValue, [&] (GPULoadOp loadOp) -> std::variant<PAL::WebGPU::LoadOp, float> {
                return WebCore::convertToBacking(loadOp);
            }, [&] (float f) -> std::variant<PAL::WebGPU::LoadOp, float> {
                return f;
            }),
            WebCore::convertToBacking(depthStoreOp),
            depthReadOnly,
            WTF::switchOn(stencilLoadValue, [&] (GPULoadOp loadOp) -> std::variant<PAL::WebGPU::LoadOp, PAL::WebGPU::StencilValue> {
                return WebCore::convertToBacking(loadOp);
            }, [&] (GPUStencilValue stencilValue) -> std::variant<PAL::WebGPU::LoadOp, PAL::WebGPU::StencilValue> {
                return stencilValue;
            }),
            WebCore::convertToBacking(stencilStoreOp),
            stencilReadOnly,
        };
    }

    GPUTextureView* view { nullptr };

    std::variant<GPULoadOp, float> depthLoadValue;
    GPUStoreOp depthStoreOp { GPUStoreOp::Store };
    bool depthReadOnly { false };

    std::variant<GPULoadOp, GPUStencilValue> stencilLoadValue;
    GPUStoreOp stencilStoreOp { GPUStoreOp::Store };
    bool stencilReadOnly { false };
};

}
